# Package `dipwmsearch`

## Description
This package provides efficient functions to search for one kind of probabilistic motifs known as *di-nucleotidic Position Weight Matrices* (di-PWMs) in a genomic sequence. The genomic sequence may contain positions with non-ATGC symbols, encoded with IUPAC.


## Documentation
A full [documentation](https://rivals.lirmm.net/dipwmsearch/) details how to install and use the package, and also provides ready-to-use scripts for searching a motif in FASTA sequence. 

**Please refer to**:   [https://rivals.lirmm.net/dipwmsearch/](https://rivals.lirmm.net/dipwmsearch/) 


**Contact**: [dipwm@lirmm.fr](mailto:dipwm@lirmm.fr)

## License
License type: [CeCILL-B](https://cecill.info/licences/Licence_CeCILL-B_V1-en.html)

## Authors
- Marie Mille (main contributor)
- Bastien Cazaux
- Julie Ripoll
- [Eric Rivals](https://www.lirmm.fr/~rivals/)

## Dependencies
### Basics to install
- `pyahocorasick`
   [documentation](https://pyahocorasick.readthedocs.io/en/latest/index.html)
   
### For tests
- `pytest`
- `pandas`
